#
# spec file for package luckybackup
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           luckybackup
Version:        0.5.0
Release:        lp151.1.2
Summary:        A backup and sync tool
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Backup
URL:            http://luckybackup.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       polkit
Requires:       rsync
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
luckyBackup is an application that backs-up and/or synchronizes any directories
with rsync.

It checks all declared directories before proceeding with any data
manipulation, and, by way of rsync, transfers only changes and not
all data.

%prep
%setup -q
# Fix permissions (fixes rpmlint errors "spurious-executable-perm" and "executable-docs")
chmod 644 manual/index.html

%build
%qmake5 QMAKE_CXXFLAGS+="%{optflags}" -config release luckybackup.pro
make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install

# Remove unneeded files
rm -rf %{buildroot}%{_datadir}/doc/luckybackup/
rm -rf %{buildroot}%{_datadir}/menu/

%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} Qt Utility Archiving
%suse_update_desktop_file -r %{name}-su Qt Utility Archiving
%endif

%files
%doc license/ manual/ readme/*
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_bindir}/luckybackup*
%{_datadir}/applications/luckybackup*.desktop
%{_datadir}/luckybackup/
%{_datadir}/pixmaps/luckybackup.*
%{_datadir}/polkit-1/actions/net.luckybackup.su.policy
%{_mandir}/man8/luckybackup*.8%{?ext_man}

%changelog
* Thu Jan 17 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Mon Nov 19 2018 ecsos@opensuse.org
- update to 0.5.0
  * Added PolicyKit integration to be able to run the gui with
    super-user privileges
- Drop desktop_files_fix.patch, because no more need.
- Rebase spec whereby spec-cleaner.
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 0.4.9
  * Various changes due to Qt5 compatibility
  * Minor modify dialog fixes
  * Fixed issue: libpng 1.6+ iCCP warnings
  * Fixed issue: compiler warning - overflow in implicit constant
    conversion
  * Fixed issue: segfault when exiting app at certain circumstances
  * Fixed issue: qfiledialog, QDataStream inclusion
- change to Qt5
- rebase desktop_files_fix.patch
* Fri Mar 28 2014 ecsos@opensuse.org
- Update to 0.4.8:
  * Added option to disable TLS for email reports
  * Added some (useful) statistics at the end of a profile run
  * Added destination disk free space at information window
  * Minor modifications to "modify task" dialog
  * View of remote places is now available through
    the "manage backup" dialog
  * Default email options are now loaded when a new profile is
    created
  * Split of full email command to command & arguments
  * Changed the default exclude "system folders"
    from "/dev /proc /sys /var" to "/dev /proc /sys /run /var/run"
  * Safety checks of mount-points now include deeper levels
    in paths than /media/<1st-level>/ and /mnt/<1st-level>/
  * Added support for vss implementation (windows)
  * Added support for nt-streams (windows)
  * Added support for e-mail notifications (windows)
  * Added various libs used for the windows port
  * Fixed issue: When one or more items were manually removed
    from an existing schedule list, LB would delete entries
    from the bottom of the list instead, when the cronIT button
    is pressed.
  * Fixed issue: Progress bar did not update normally
  * Fixed issue: Segmentation fault under certain circumstances,
    when --skip-critical is used as an argument and there exists
    one or more actual CRITICAL tasks.
  * Fixed issue: Confusion at task list when an item's box state
    changed.
  * Fixed issue (windows): Warning message regarding
    the changes.log files during a run
* Sat Mar 24 2012 asterios.dramis@gmail.com
- Update to 0.4.7:
  * Introduced compatibility for the windows port
  * Improved OS2 compatibility for snapshots
  * Added option to compress the logfile before sending it via e-mail
  * Added next/previous error buttons at commands output window
  * Added feature to backup profile, log and snapshot data to the destination
    after a task run
  * Added protection rule: Exclude list is disabled when user selects "only
    include", to avoid confusion
  * Added a "repeat-on-fail" feature for running tasks
  * Added "quite mode" during run, to only display errors and important
    messages
  * Added the ".gvfs" folder as an exclude template
  * Added "--super" and "--numeric-ids" as command options templates
  * Added option to schedule profile runs on an hourly basis
  * Changed the global settings file from Qvariant to simple text
  * Changed the schedule file from Qvariant to simple text
  * Changed the profile import/export feature so that logs and snapshot data
    are included too
  * Fixed issue: email fetaure sent the oldest logfile instead of the newest
    one
  * Fixed issue: email feature reported "process timeout"
  * Fixed various issues when spaces are used at a remote path
  * Fixed issue: Creation of the snapshot directory at a remote destination
    when the max No. of snapshots was not reached
  * Fixed issue: wrong snapshot directory name when remote source was used
  * Updated manual
- Rebased desktop_files_fix.patch to apply cleanly.
* Fri Jun 17 2011 asterios.dramis@gmail.com
- Update to 0.4.6:
  * Fixed issue: Older snapshots restore did not always work as expected
  * Fixed issue: ".changes.log" files sometimes did not update their lines
    normaly
  * Improved gui. Thank you Michael :)
  * Changed default help browser size
  * Increased the limit of maximum snapshots
  * Improved OS2 compatibility for snapshots
  * Updated manual
- Fixed rpmlint errors "spurious-executable-perm" and "executable-docs".
* Thu Mar 10 2011 asterios.dramis@gmail.com
- Update to 0.4.5:
  * Added feature to email a report after backup
  * Added a "shutdown system when finished" feature (looks much cooler within
    kde)
  * Added move & edit options for the "exclude", "include", "command options"
    and "also execute" lists of items
  * Added option to delay @reboot scheduled jobs so as to allow the graphical
    environment to launch
  * Added conditional statements (stop task execution on error) for the "also
    execute" commands, in the form of a check-box
  * Added a command line argument to display current application version
  * Added extra directory check for mounted filesystems under /media or /mnt
  * Added actions after a profile/task rename, removal or deletion that will
    pass the changes to the snapshot & log files
  * Changed tray baloon notification to something that does not remind of
    windowz (only for kde-normal user)
  * Reduced the 2 backup task types to 1 and added a checkbox instead. Seemed
    like the 2 backup types were confusing to many
  * Save profile button is now greyed when not needed
  * Various (well, lots actually) changes to make LB more "OS/2 compatible"
  * Fixed issue: Useless lines accumulating within .profile files
  * Fixed issue: When the gpl license is not available no feedback to user was
    available
  * Fixed issue: Profile actions toolbar was not visible when gui run from
    command-line with a profile argument
  * Fixed issue: Profile execution pause, when an "also execute" command
    reported error (eg fail to start, timeout etc)
  * Updated manpage
  * Updated manual
- Spec file updates:
  * Changed License: to GPLv3+.
  * Updates in Group:, Summary: and %%description.
  * Updates in %%files section.
* Fri Jan 21 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires:, Requires:, %%build and %%install sections.
  * Merged luckybackup-doc into the main package.
  * Fixed rpm post build checks warnings (empty debuginfo/debugsource package,
    File is compiled without RPM_OPT_FLAGS).
- Added a patch to fix the desktop files (Fix Exec=, Icon= and Categories
  entries, use xdg-su for root execution).
* Sun Nov 21 2010 bitshuffler@opensuse.org
- Update to 0.4.4
  * Fixed issue: Displayed task last execution time at the main window,
    was always "not available" (thank you Michele)
  * Added support for snapshots when remote destination is used
* Sat Sep  4 2010 tittiatcoke@gmail.com
- Update to 0.4.3
  * Added extra description field for profiles and individual tasks.
  * Change .profile files to simple text so that they can be
    edited directly (original profiles are backed-up to
    ~/.luckyBackup/profiles/backups/ just in case).
  * Improved logviewer to handle huge files much faster.
  * Fixed issue: Normal user menu entry title is "luckybackup
    (super user)".
  * Fixed issue: When using remote destination, a directory named
    exactly as the destination, will be created localy.
  * Fixed issue: Non-workings links inside manual, when application
    is run from command-line
  * Fixed issue: The gui freezes when huge amount of information
    is desplayed in the "commands output" window
  * Updated manual
  * Fixed issue: Fail to add a new schedule, due to an
    "invalid profile" message.
  * Fixed annoying gui freeze while calculating differences between
    a snapshot & the source. Also added a "STOP caclulations" button.
  * Fixed issue: Seg fault occurs when a system tray notification
    area is not available and LB is minimized to tray (eg scheduled jobs).
  * Minor gui improvements.
* Wed Aug 11 2010 bitshuffler@opensuse.org
- Add luckybackup-0.4.1-desktop.patch to fix bnc#621379
* Sat Jun 19 2010 bitshuffler@opensuse.org
- Update to 0.4.1
* Tue May 18 2010 bitshuffler@opensuse.org
- Updated to 0.4.0
* Fri Dec 18 2009 tittiatcoke@gmail.com
- Updated to 0.3.5
  * BUG fix: Segmentation fault (window vanishes) produced when adding
    a new task
  * Improved logfiles to a much more useable format
  * Added cool "pattern editor"
  * Added tray notification support
  * Changed "delete files on the destination" as a default option again,
    together with a WARNING message
  * Added "by-pass WARNING" option as a task property, so that the user
    has the ability to execute tasks with a WARNING message
  * Added more command line arguments so that that the gui executes
    the profile given as argument in normal, dry-run or silent mode
  * Improved (simplified) input of a valid profile at command-line mode
  * Indroduced error codes at console mode
  * Improved schedule settings file (please excuse me for no compatibility
    with older versions)
  * Minor "task properties" dialog improvements
  * Introduced information messages regarding schedules
  * Introduced information messages regarding the current user running LB
  * Fixed schedule dialog bug. When one schedule existed the modify option
    did not work correctly
  * Added refresh list function, after a profile execution to update the gui
  * Updated manpage
  * Minor gui improvements
    for the complete changelog, please visit:
    http://luckybackup.sourceforge.net/changelog.html
* Sun Aug  2 2009 bitshuffler@opensuse.org
- Updated to 0.3.3
* Sun Jun  7 2009 bitshuffler@opensuse.org
- Updated to 0.3.2
* Tue May 12 2009 bitshuffler@opensuse.org
- Updated to 0.3
* Mon Mar 16 2009 bitshuffler@opensuse.org
- Updated to 0.2.2
* Fri Mar 13 2009 bitshuffler@opensuse.org
- Updated to 0.2.1.1
* Tue Feb 10 2009 bitshuffler@opensuse.org
- Updated to 0.2.1
* Mon Jan  7 2008 bitshuffler@opensuse.org
- Initial RPM
